==> localnews-admin-service-1.4.3-20190717.090336-3-sources.jar: com/bxm/localnews/admin/service/base/impl/AdminAppVersionServiceImpl.java <==
package com.bxm.localnews.admin.service.base.impl;

import com.bxm.localnews.admin.constant.RedisConfig;
import com.bxm.localnews.admin.constant.VersionForceEnum;
import com.bxm.localnews.admin.domain.AdminAppVersionMapper;
import com.bxm.localnews.admin.dto.AppVersionDTO;
import com.bxm.localnews.admin.param.AppVersionParam;
import com.bxm.localnews.admin.service.base.AdminAppVersionService;
import com.bxm.localnews.admin.service.base.AdminChannelService;
import com.bxm.localnews.admin.vo.AppVersion;
import com.bxm.localnews.admin.vo.Channel;
import com.bxm.newidea.component.redis.KeyGenerator;
import com.bxm.newidea.component.redis.RedisStringAdapter;
import com.bxm.newidea.component.tools.StringUtils;
import com.bxm.newidea.component.uuid.SequenceCreater;
import com.bxm.newidea.component.vo.PageWarper;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;

/**
 * @author zhaoyadong 2019/1/10 15:35
 * @desc
 */
@Service
public class AdminAppVersionServiceImpl implements AdminAppVersionService {

    private AdminAppVersionMapper adminAppVersionMapper;

    private AdminChannelService adminChannelService;

    private RedisStringAdapter redisStringAdapter;

    private SequenceCreater sequenceCreater;

    @Autowired
    public AdminAppVersionServiceImpl(AdminAppVersionMapper adminAppVersionMapper, AdminChannelService adminChannelService,
                                      RedisStringAdapter redisStringAdapter, SequenceCreater sequenceCreater) {
        this.adminAppVersionMapper = adminAppVersionMapper;
        this.adminChannelService = adminChannelService;
        this.redisStringAdapter = redisStringAdapter;
        this.sequenceCreater = sequenceCreater;
    }

    @Override
    public PageWarper<AppVersionDTO> getAppVersionList(AppVersionParam appVersionParam) {

        PageWarper<AppVersionDTO> pageWarper = new PageWarper<AppVersionDTO>(this.adminAppVersionMapper.getAppVersionList(appVersionParam));
        pageWarper.getList().forEach(appVersionDTO -> {
            Channel channel = this.adminChannelService.selectById(appVersionDTO.getChannelId());
            appVersionDTO.setMobileType(channel.getMobileType());
            appVersionDTO.setName(channel.getName());
            appVersionDTO.setCode(channel.getCode());
        });

        return pageWarper;
    }

    @Override
    public AppVersionDTO getAppVersionById(Long id) {
        AppVersionDTO appVersionDTO = new AppVersionDTO();
        AppVersion appVersion = this.adminAppVersionMapper.selectByPrimaryKey(id);
        BeanUtils.copyProperties(appVersion, appVersionDTO);
        Channel channel = this.adminChannelService.selectById(appVersionDTO.getChannelId());
        appVersionDTO.setMobileType(channel.getMobileType());
        appVersionDTO.setName(channel.getName());
        appVersionDTO.setCode(channel.getCode());
        return appVersionDTO;
    }

    @Override
    public int updateAppVersionStatusById(String[] ids, Byte status, Byte force) {
        return this.adminAppVersionMapper.updateAppVersionStatusById(ids, status, force);
    }

    @Override
    public int updateAppVersionStatusById(AppVersion appVersion) {
        AppVersion oldAppVersion = this.adminAppVersionMapper.selectByPrimaryKey(appVersion.getId());
        if (oldAppVersion == null) {
            return 0;
        }

        this.adminAppVersionMapper.updateByPrimaryKeySelective(appVersion);
        removeCache();

        return 1;
    }

    @Override
    public int addAppVersionDetail(AppVersion appVersion) {
        Long appVersionId = appVersion.getId();
        if (appVersionId == null) {
            appVersionId = sequenceCreater.nextLongId();
        }

        int update;
        if (!VersionForceEnum.FORCE_UPDATE.getState().equals(appVersion.getForce())) {
            appVersion.setForceVersion(StringUtils.EMPTY);
        }

        //设置为审核状态---则关闭
        if (appVersion.getStatus() == 1) {
            appVersion.setEnable((byte) 0);
        }

        if (appVersion.getId() == null) {
            appVersion.setId(appVersionId);
            appVersion.setCreateTime(new Date());
            update = this.adminAppVersionMapper.insertSelective(appVersion);
        } else {
            update = this.adminAppVersionMapper.updateByPrimaryKeySelective(appVersion);
        }
        //业务端进行版本判断强制更新的范围
        //        if (StringUtils.isNotBlank(appVersion.getForceVersion())) {
        //            AppVersion version = this.adminAppVersionMapper.getAppVersionByVersion(appVersion.getChannelId(),
        //                    appVersion.getForceVersion());
        //            if (version != null) {
        //                this.adminAppVersionMapper.updateForceByVersion(appVersion.getChannelId(), version.getCreateTime());
        //            }
        //        }

        removeCache();
        return update;
    }

    /**
     * 获取版本信息key
     * @return
     */
    private KeyGenerator getAppVersionKey() {
        return RedisConfig.BASE_APPVERSION_CHANNEL.copy().appendKey("list");
    }

    /**
     * 移除缓存信息
     */
    private void removeCache() {
        redisStringAdapter.remove(getAppVersionKey());
    }
}

==> localnews-admin-service-3.12.0-sources.jar: com/bxm/localnews/admin/service/base/impl/AdminAppVersionServiceImpl.java <==
package com.bxm.localnews.admin.service.base.impl;

import com.bxm.localnews.admin.constant.RedisConfig;
import com.bxm.localnews.admin.enums.VersionForceEnum;
import com.bxm.localnews.admin.domain.AdminAppVersionMapper;
import com.bxm.localnews.admin.dto.AppVersionDTO;
import com.bxm.localnews.admin.param.AppVersionParam;
import com.bxm.localnews.admin.service.base.AdminAppVersionService;
import com.bxm.localnews.admin.service.base.AdminChannelService;
import com.bxm.localnews.admin.vo.AppVersion;
import com.bxm.localnews.admin.vo.Channel;
import com.bxm.newidea.component.redis.KeyGenerator;
import com.bxm.newidea.component.redis.RedisStringAdapter;
import com.bxm.newidea.component.tools.StringUtils;
import com.bxm.newidea.component.uuid.SequenceCreater;
import com.bxm.newidea.component.vo.PageWarper;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.Date;

/**
 * @author zhaoyadong 2019/1/10 15:35
 * @desc
 */
@Service
public class AdminAppVersionServiceImpl implements AdminAppVersionService {

    private AdminAppVersionMapper adminAppVersionMapper;

    private AdminChannelService adminChannelService;

    private RedisStringAdapter redisStringAdapter;

    private SequenceCreater sequenceCreater;

    @Autowired
    public AdminAppVersionServiceImpl(AdminAppVersionMapper adminAppVersionMapper, AdminChannelService adminChannelService,
                                      RedisStringAdapter redisStringAdapter, SequenceCreater sequenceCreater) {
        this.adminAppVersionMapper = adminAppVersionMapper;
        this.adminChannelService = adminChannelService;
        this.redisStringAdapter = redisStringAdapter;
        this.sequenceCreater = sequenceCreater;
    }

    @Override
    public PageWarper<AppVersionDTO> getAppVersionList(AppVersionParam appVersionParam) {

        PageWarper<AppVersionDTO> pageWarper = new PageWarper<AppVersionDTO>(this.adminAppVersionMapper.getAppVersionList(appVersionParam));
        pageWarper.getList().forEach(appVersionDTO -> {
            Channel channel = this.adminChannelService.selectById(appVersionDTO.getChannelId());
            appVersionDTO.setMobileType(channel.getMobileType());
            appVersionDTO.setName(channel.getName());
            appVersionDTO.setCode(channel.getCode());
        });

        return pageWarper;
    }

    @Override
    public AppVersionDTO getAppVersionById(Long id) {
        AppVersionDTO appVersionDTO = new AppVersionDTO();
        AppVersion appVersion = this.adminAppVersionMapper.selectByPrimaryKey(id);
        BeanUtils.copyProperties(appVersion, appVersionDTO);
        Channel channel = this.adminChannelService.selectById(appVersionDTO.getChannelId());
        appVersionDTO.setMobileType(channel.getMobileType());
        appVersionDTO.setName(channel.getName());
        appVersionDTO.setCode(channel.getCode());
        return appVersionDTO;
    }

    @Override
    public int updateAppVersionStatusById(String[] ids, Byte status, Byte force) {
        return this.adminAppVersionMapper.updateAppVersionStatusById(ids, status, force);
    }

    @Override
    public int updateAppVersionStatusById(AppVersion appVersion) {
        AppVersion oldAppVersion = this.adminAppVersionMapper.selectByPrimaryKey(appVersion.getId());
        if (oldAppVersion == null) {
            return 0;
        }

        this.adminAppVersionMapper.updateByPrimaryKeySelective(appVersion);
        removeCache();

        return 1;
    }

    @Override
    public int addAppVersionDetail(AppVersion appVersion) {
        Long appVersionId = appVersion.getId();
        if (appVersionId == null) {
            appVersionId = sequenceCreater.nextLongId();
        }

        int update;
        if (!VersionForceEnum.FORCE_UPDATE.getState().equals(appVersion.getForce())) {
            appVersion.setForceVersion(StringUtils.EMPTY);
        }

        //设置为审核状态---则关闭
        if (appVersion.getStatus() == 1) {
            appVersion.setEnable((byte) 0);
        }

        if (appVersion.getId() == null) {
            appVersion.setId(appVersionId);
            appVersion.setCreateTime(new Date());
            update = this.adminAppVersionMapper.insertSelective(appVersion);
        } else {
            update = this.adminAppVersionMapper.updateByPrimaryKeySelective(appVersion);
        }
        //业务端进行版本判断强制更新的范围
        //        if (StringUtils.isNotBlank(appVersion.getForceVersion())) {
        //            AppVersion version = this.adminAppVersionMapper.getAppVersionByVersion(appVersion.getChannelId(),
        //                    appVersion.getForceVersion());
        //            if (version != null) {
        //                this.adminAppVersionMapper.updateForceByVersion(appVersion.getChannelId(), version.getCreateTime());
        //            }
        //        }

        removeCache();
        return update;
    }

    /**
     * 获取版本信息key
     * @return
     */
    private KeyGenerator getAppVersionKey() {
        return RedisConfig.BASE_APPVERSION_CHANNEL.copy().appendKey("list");
    }

    /**
     * 移除缓存信息
     */
    private void removeCache() {
        redisStringAdapter.remove(getAppVersionKey());
    }
}
